# Carbon2 System API

Provide a toolkit for Carbon2 system APIs

## Installation
```pip
pip install carbon2
```

## License
The `carbon2` project is provided by [Donghua Chen](https://github.com/dhchenx). 

